/*
 * Meviz - Various tools collection to work with multimedia.
 * Copyright (C) 2012 -- 2018, Svjatoslav Agejenko, svjatoslav@svjatoslav.eu
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of version 2 of the GNU General Public License
 * as published by the Free Software Foundation.
 */

package eu.svjatoslav.meviz;

import eu.svjatoslav.meviz.encoder.Encoder;

import java.util.ArrayList;

class Main {

    private static ArrayList<Module> modules;

    private static String[] getRemainingOptions(final String[] options) {
        final String[] remainingOptions = new String[options.length - 1];

        System.arraycopy(options, 1, remainingOptions, 0, options.length - 1);

        return remainingOptions;
    }

    private static void initModules() {
        modules = new ArrayList<>();

        modules.add(new Encoder());
        modules.add(new eu.svjatoslav.meviz.htmlindexer.Main());
        modules.add(new eu.svjatoslav.meviz.renamer.Main());
        modules.add(new eu.svjatoslav.meviz.grabmemcard.Main());
        modules.add(new eu.svjatoslav.meviz.bomremove.Main());
        modules.add(new eu.svjatoslav.meviz.replace.Main());
    }

    public static void main(final String[] args) throws Exception {

        initModules();

        if (args.length < 1)
            showHelp();
        else if (args[0].equals("help")) {
            if (args.length != 2)
                showHelp();
            else {

                for (final Module module : modules)
                    if (args[1].equals(module.getModuleCommand())) {
                        module.showCommandlineHelp();
                        return;
                    }

                System.out.println("Error: unrecognized module by name:"
                        + args[1] + "\n");
                showHelp();

            }
        } else {

            for (final Module module : modules)
                if (args[0].equals(module.getModuleCommand())) {
                    module.run(getRemainingOptions(args));
                    return;
                }

            System.out.println("Error: unrecognized commandline option:"
                    + args[0] + "\n");
            showHelp();
        }

    }

    private static void showHelp() {
        final StringBuilder buffer = new StringBuilder();

        buffer.append("Commandline options: \n"
                + "help\n    show this help screen \n\n");

        buffer.append("help <module>\n    show module specific help screen\n\n");

        buffer.append("Available modules:\n\n");

        for (final Module module : modules) {
            buffer.append(module.getModuleCommand() + "\n");
            buffer.append("    " + module.getDescription() + "\n\n");
        }

        System.out.println(buffer.toString());
    }
}
