/*
 * Meviz - Various tools collection to work with multimedia.
 * Copyright (C) 2012 -- 2018, Svjatoslav Agejenko, svjatoslav@svjatoslav.eu
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of version 2 of the GNU General Public License
 * as published by the Free Software Foundation.
 */

package eu.svjatoslav.meviz.encoder;

import eu.svjatoslav.commons.commandline.parameterparser.ArgumentCount;
import eu.svjatoslav.commons.commandline.parameterparser.Parameter;

public class BitrateParameter extends Parameter<BitrateParameter.Bitrate, BitrateParameter> {

    public BitrateParameter(final String description) {
        super(description, ArgumentCount.SINGLE);
    }

    @Override
    public String describeFormat() {
        return "Target bitrate [NONE / LOW / MEDIUM / HIGH / COPY ]";
    }

    @Override
    public Bitrate getValue() {
        return Bitrate.valueOf(arguments.get(0).toUpperCase());
    }

    @Override
    public boolean validate(final String value) {
        try {
            Bitrate.valueOf(value.toUpperCase());
        } catch (final IllegalArgumentException exception) {
            return false;
        }

        return true;
    }

    public enum Bitrate {
        NONE, LOW, MEDIUM, HIGH, COPY
    }
}
