/*
 * Meviz - Various tools collection to work with multimedia.
 * Copyright (C) 2012 -- 2018, Svjatoslav Agejenko, svjatoslav@svjatoslav.eu
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of version 2 of the GNU General Public License
 * as published by the Free Software Foundation.
 */

package eu.svjatoslav.meviz.encoder;

import eu.svjatoslav.meviz.encoder.converters.*;

import java.util.ArrayList;
import java.util.List;

public class FormatsRegistry {

    private final ArrayList<AbstractConverter> encoders = new ArrayList<>();

    public FormatsRegistry() {
        // video conversion
        registerEncoder(new Ffmpeg2theora());
        registerEncoder(new AvconvVideo());

        // image conversion
        registerEncoder(new Convert());

        // image to text (OCR)
        registerEncoder(new Ocr());

        // audio conversion
        registerEncoder(new Ogg2Wav());
        registerEncoder(new Flac());
        registerEncoder(new AvconvAudio());
        registerEncoder(new Midi2Wav());
    }

    public List<AbstractConverter> getEncoders(final String sourceFormat,
                                               final String targetFormat) {

        final String sourceFormatLowerCase = sourceFormat.toLowerCase();
        final String targetFormatLowerCase = targetFormat.toLowerCase();

        final ArrayList<AbstractConverter> encoders = new ArrayList<>();

        for (final AbstractConverter encoder : this.encoders)
            if (encoder.supportsSource(sourceFormatLowerCase))
                if (encoder.supportsTarget(targetFormatLowerCase)) {
                    encoders.add(encoder);
                    return encoders;
                }

        return encoders;
    }

    private void registerEncoder(final AbstractConverter encoder) {
        encoders.add(encoder);
    }

}
