/*
 * Meviz - Various tools collection to work with multimedia.
 * Copyright (C) 2012 -- 2018, Svjatoslav Agejenko, svjatoslav@svjatoslav.eu
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of version 2 of the GNU General Public License
 * as published by the Free Software Foundation.
 */

package eu.svjatoslav.meviz.htmlindexer.metadata;

import java.io.Serializable;

/**
 * Corresponds to single image dimensions.
 */

public class Dimension implements Serializable, Comparable<Dimension> {

    private static final long serialVersionUID = -1039288266937331829L;

    public int width;
    public int height;

    private Dimension() {
        width = 0;
        height = 0;
    }

    public Dimension(final Dimension origial) {
        width = origial.width;
        height = origial.height;
    }

    public Dimension(final int width, final int height) {
        this.width = width;
        this.height = height;
    }

    @Override
    public int compareTo(final Dimension anotherDimension) {
        if (width < anotherDimension.width)
            return -1;
        if (width > anotherDimension.width)
            return 1;

        if (height < anotherDimension.height)
            return -1;
        if (height > anotherDimension.height)
            return 1;

        return 0;
    }

    public boolean equals(final Dimension anotherDimension) {
        return compareTo(anotherDimension) == 0;
    }

    public int getArea() {
        return width * height;
    }

    public java.awt.Dimension getAwtDimension() {
        return new java.awt.Dimension(width, height);
    }

    public Dimension getScaled(final double multiplicationFactor) {
        final Dimension result = new Dimension();

        result.width = (int) ((width) * multiplicationFactor);
        result.height = (int) ((height) * multiplicationFactor);

        return result;
    }

    @Override
    public String toString() {
        return "Dimension [width=" + width + ", height=" + height + "]";
    }

}
