/*
 * Meviz - Various tools collection to work with multimedia.
 * Copyright (C) 2012 -- 2018, Svjatoslav Agejenko, svjatoslav@svjatoslav.eu
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of version 2 of the GNU General Public License
 * as published by the Free Software Foundation.
 */

package eu.svjatoslav.meviz.htmlindexer.metadata;

import eu.svjatoslav.commons.file.IOHelper;
import org.apache.log4j.Logger;

import java.io.*;

public class MetadadaHelper {

    private static final Logger logger = Logger.getLogger(MetadadaHelper.class);

    /**
     * Load previously generated or initialize new directory metadata.
     */
    public static DirectoryMetadata initDirectoryMetadata(
            final File metadataFile) {

        if (!metadataFile.exists())
            return new DirectoryMetadata();
        else
            try {

                final ObjectInputStream in = new ObjectInputStream(
                        new FileInputStream(metadataFile));
                final DirectoryMetadata directory = (DirectoryMetadata) in
                        .readObject();
                in.close();

                return directory;

            } catch (final Exception exception) {
                logger.error("Cannot load existing directory metadata.",
                        exception);

                return new DirectoryMetadata();
            }
    }

    public static void saveDirectoryMetadata(final File persistanceFile,
                                             final DirectoryMetadata directory) throws IOException {
        // serialize directory metadata into byte array
        final ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream();

        final ObjectOutputStream out = new ObjectOutputStream(
                byteArrayOutputStream);
        out.writeObject(directory);
        out.close();

        // store byte array into file
        IOHelper.saveToFile(persistanceFile,
                byteArrayOutputStream.toByteArray());
    }
}
