/*
 * Meviz - Various tools collection to work with multimedia.
 * Copyright (C) 2012 -- 2018, Svjatoslav Agejenko, svjatoslav@svjatoslav.eu
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of version 2 of the GNU General Public License
 * as published by the Free Software Foundation.
 */

package eu.svjatoslav.meviz.renamer;

import eu.svjatoslav.commons.commandline.parameterparser.Parser;
import eu.svjatoslav.commons.commandline.parameterparser.parameter.DirectoryParameter;
import eu.svjatoslav.commons.commandline.parameterparser.parameter.NullParameter;
import eu.svjatoslav.commons.commandline.parameterparser.parameter.StringParameter;
import eu.svjatoslav.commons.commandline.parameterparser.parameter.StringParameters;
import eu.svjatoslav.meviz.encoder.EncodingOptions;

import java.io.File;

class CommandlineHandler {

    final Parser parser = new Parser();

    private final NullParameter recursiveParameter = parser.add(
            new NullParameter("Enable recursive mode.")).addAliases("-r",
            "--recursive");

    private final NullParameter testParameter = parser.add(
            new NullParameter(
                    "Simulate renaming (no changes will be actually done)."))
            .addAliases("-t", "--test");

    private final StringParameter outputPatternParameter = parser.add(
            new StringParameter("Output pattern.")).addAliases("-o",
            "--output-pattern");

    private final StringParameters inputPatternParameter = parser.add(
            new StringParameters("File input pattern.")).addAliases("-i",
            "--input-pattern");

    private final DirectoryParameter workingDirectoryParameter = parser
            .add(new DirectoryParameter("Working directory."))
            .addAliases("-w", "--working-directory").mustExist();

    /**
     * @return {@link EncodingOptions} if commandline arguments were
     * successfully parsed, or <code>null</code> if parsing error
     * occurred.
     */
    public RenamingOptions parseCommandlineArguments(final String[] args) {

        final RenamingOptions options = new RenamingOptions();

        if (!parser.parse(args))
            return null;

        if (testParameter.isSpecified())
            options.testOnly = true;

        if (recursiveParameter.isSpecified())
            options.recursive = true;

        if (outputPatternParameter.isSpecified())
            options.outputPattern = outputPatternParameter.getValue();

        if (workingDirectoryParameter.isSpecified())
            options.targetDirectory = workingDirectoryParameter.getValue();
        else
            options.targetDirectory = new File(System.getProperty("user.dir"));

        // TODO: add multiple input patterns support
        if (inputPatternParameter.isSpecified())
            options.inputPatterns.addAll(inputPatternParameter.getValue());

        return options;
    }
}
