/*
 * Meviz - Various tools collection to work with multimedia.
 * Copyright (C) 2012 -- 2018, Svjatoslav Agejenko, svjatoslav@svjatoslav.eu
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of version 2 of the GNU General Public License
 * as published by the Free Software Foundation.
 */

package eu.svjatoslav.meviz.replace;

import eu.svjatoslav.commons.commandline.parameterparser.Parser;
import eu.svjatoslav.commons.commandline.parameterparser.parameter.DirectoryParameter;
import eu.svjatoslav.commons.commandline.parameterparser.parameter.NullParameter;
import eu.svjatoslav.commons.commandline.parameterparser.parameter.StringParameter;

import java.io.File;

class CommandlineHandler {

    final Parser parser = new Parser();

    private final NullParameter recursiveParameter = parser.add(
            new NullParameter("Enable recursive mode.")).addAliases("-r",
            "--recursive");

    private final StringParameter searchForPattern = parser
            .add(new StringParameter("String to search for"))
            .addAliases("-s", "--search-pattern").setMandatory();

    private final StringParameter replaceWithPattern = parser.add(
            new StringParameter("String to place instead")).addAliases("-p",
            "--replace-pattern");

    private final DirectoryParameter directoryParameter = parser
            .add(new DirectoryParameter("Working directory."))
            .addAliases("-w", "--working-directory").mustExist();

    public CommandlineOptions parseCommandlineArguments(final String[] args) {

        final CommandlineOptions options = new CommandlineOptions();

        if (!parser.parse(args))
            return null;

        if (recursiveParameter.isSpecified())
            options.recursive = true;

        if (directoryParameter.isSpecified())
            options.targetDirectory = directoryParameter.getValue();
        else
            options.targetDirectory = new File(System.getProperty("user.dir"));

        if (searchForPattern.isSpecified())
            options.searchForPattern = searchForPattern.getValue();

        if (replaceWithPattern.isSpecified())
            options.replaceWithPattern = replaceWithPattern.getValue();

        return options;
    }
}
