/*
 * Meviz - Various tools collection to work with multimedia.
 * Copyright (C) 2012 -- 2018, Svjatoslav Agejenko, svjatoslav@svjatoslav.eu
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of version 2 of the GNU General Public License
 * as published by the Free Software Foundation.
 */

package eu.svjatoslav.meviz.replace;

import eu.svjatoslav.meviz.Module;

import java.io.*;

public class Main implements Module {

    private final CommandlineHandler commandlineHandler = new CommandlineHandler();

    private CommandlineOptions options;

    @Override
    public String getDescription() {
        return "Replace one string to another string in all occurrances and all files recursively.";
    }

    @Override
    public String getModuleCommand() {
        return "replace";
    }

    private void processDirectory(final File directory) {

        for (final File file : directory.listFiles())
            if (file.isDirectory()) {
                if (options.recursive)
                    processDirectory(file);
            } else
                try {
                    processFile(file);
                } catch (final IOException exception) {
                    System.out.println("Error processing file: "
                            + file.getAbsolutePath());
                    System.out.println("   exception: "
                            + exception.getMessage());
                }

    }

    private void processFile(final File file) throws IOException {

        final FileReader fileReader = new FileReader(file);
        final BufferedReader bufferedReader = new BufferedReader(fileReader);

        final StringBuilder result = new StringBuilder();

        boolean contentChanged = false;

        while (true) {
            final String line = bufferedReader.readLine();
            if (line == null)
                break;

            final String newLine = line.replace(options.searchForPattern,
                    options.replaceWithPattern);

            if (!contentChanged)
                if (!newLine.equals(line))
                    contentChanged = true;

            result.append(newLine);
            result.append("\n");
        }

        bufferedReader.close();
        fileReader.close();

        if (contentChanged) {
            final FileWriter fileWriter = new FileWriter(file);
            fileWriter.write(result.toString());
            fileWriter.close();
        }

    }

    @Override
    public void run(final String[] args) throws IOException {

        options = commandlineHandler.parseCommandlineArguments(args);

        if (options == null) {
            showCommandlineHelp();
            return;
        }

        processDirectory(options.targetDirectory);

    }

    @Override
    public void showCommandlineHelp() {
        commandlineHandler.parser.showHelp();
    }

}
